"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _reactHelmet = require("react-helmet");
var _reactIntl = require("react-intl");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const propTypes = {
  csrf: _propTypes.default.object,
  error: _propTypes.default.string,
  isLogoutSuccess: _propTypes.default.bool,
  intl: _reactIntl.intlShape.isRequired,
  tenantId: _propTypes.default.string
};
const defaultProps = {
  csrf: null,
  error: null,
  isLogoutSuccess: false,
  tenantId: null
};
const messages = (0, _reactIntl.defineMessages)({
  title: {
    "id": "serviceLoginPage.title",
    "defaultMessage": "Sign in"
  },
  prompt: {
    "id": "serviceLoginPage.prompt",
    "defaultMessage": "Please sign in to continue."
  },
  username: {
    "id": "serviceLoginPage.username",
    "defaultMessage": "Email"
  },
  password: {
    "id": "serviceLoginPage.password",
    "defaultMessage": "Password"
  },
  forgotPassword: {
    "id": "serviceLoginPage.forgotPassword",
    "defaultMessage": "Forgot password"
  },
  localLogin: {
    "id": "serviceLoginPage.localLogin",
    "defaultMessage": "Continue with email and password"
  },
  logoutSuccess: {
    "id": "serviceLoginPage.logoutSuccess",
    "defaultMessage": "Sign out complete."
  },
  errorBadCredentials: {
    "id": "serviceLoginPage.errorBadCredentials",
    "defaultMessage": "Sign in failed. Incorrect username/password."
  }
});
function ServiceLoginPage(props) {
  const {
    csrf,
    error,
    isLogoutSuccess,
    intl,
    tenantId
  } = props;
  const csrfInput = csrf ? /*#__PURE__*/_react.default.createElement("input", {
    type: "hidden",
    name: csrf.parameterName,
    value: csrf.token
  }) : undefined;
  const successMessage = isLogoutSuccess ? /*#__PURE__*/_react.default.createElement("p", {
    className: "status success"
  }, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.logoutSuccess)) : undefined;
  let formattedError;
  if (/bad credentials/i.test(error)) {
    formattedError = /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.errorBadCredentials);
  } else {
    formattedError = error;
  }
  const errorMessage = formattedError ? /*#__PURE__*/_react.default.createElement("p", {
    className: "status error"
  }, formattedError) : undefined;
  const tidParam = tenantId ? `?tid=${tenantId}` : '';
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_reactHelmet.Helmet, null, /*#__PURE__*/_react.default.createElement("title", null, intl.formatMessage(messages.title))), successMessage, errorMessage, /*#__PURE__*/_react.default.createElement("main", null, /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.prompt)), /*#__PURE__*/_react.default.createElement("form", {
    method: "POST"
  }, /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement("label", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.username), /*#__PURE__*/_react.default.createElement("input", {
    autoComplete: "username email",
    name: "username",
    type: "text"
  }))), /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement("label", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.password), /*#__PURE__*/_react.default.createElement("input", {
    autoComplete: "current-password",
    name: "password",
    type: "password"
  }))), /*#__PURE__*/_react.default.createElement("div", null, csrfInput, /*#__PURE__*/_react.default.createElement("button", {
    className: "login",
    type: "submit"
  }, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.localLogin))), /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement("a", {
    href: `./accounts/requestpasswordreset${tidParam}`
  }, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.forgotPassword))))));
}
ServiceLoginPage.propTypes = propTypes;
ServiceLoginPage.defaultProps = defaultProps;
var _default = (0, _reactIntl.injectIntl)(ServiceLoginPage);
exports.default = _default;